Struct prometheus_http_query::client::Client [−][src]
A client used to execute queries. It uses a reqwest::Client internally
that manages connections for us.
Implementations
impl Client[src]
pub fn new(scheme: Scheme, host: &str, port: u16) -> Self[src]
Create a Client that connects to a Prometheus instance at the given FQDN/domain and port, using either HTTP or HTTPS.
Note that possible errors regarding domain name resolution or
connection establishment will only be propagated from the underlying
reqwest::Client when a query is executed.
use prometheus_http_query::{Client, Scheme}; let client = Client::new(Scheme::Http, "localhost", 9090);