Enum prometheus_http_query::Scheme
source · [−]pub enum Scheme {
Http,
Https,
}Expand description
A helper enum that is passed to the Client::new function in order to avoid errors on unsupported connection schemes.
Variants
Http
Https