pub enum Data {
    Vector(Vec<InstantVector>),
    Matrix(Vec<RangeVector>),
    Scalar(Sample),
}
A wrapper for possible result types of expression queries (crate::Client::query and crate::Client::query_range).

Variants



Vector(Vec<InstantVector>)



Matrix(Vec<RangeVector>)



Scalar(Sample)

Implementations

If the result type of the query is vector, returns an array of InstantVectors. Returns None otherwise.

If the result type of the query is matrix returns an array of RangeVectors. Returns None otherwise.

If the result type of the query is scalar, returns a single Sample. Returns None otherwise.

Check if this PromqlResult contains a list of InstantVectors (i.e. result type vector).

Check if this PromqlResult contains a list of RangeVectors (i.e. result type matrix).

Check if this PromqlResult contains a scalar value (i.e. result type scalar, a single Sample).

This is a shortcut to check if the query returned any data at all regardless of the exact type.