pub enum QueryResultType {
Vector(Vec<InstantVector>),
Matrix(Vec<RangeVector>),
}Expand description
A wrapper for possible result types of expression queries (crate::Client::query and crate::Client::query_range).
Variants
Vector(Vec<InstantVector>)
Matrix(Vec<RangeVector>)
Implementations
If the result type of the query is vector, returns an array of InstantVectors. Returns None otherwise.
If the result type of the query is matrix returns an array of RangeVectors. Returns None otherwise.