pub struct ActiveTarget { /* private fields */ }
A single active target.

Implementations

Get a set of unmodified labels as before relabelling occurred.

Get a set of labels after relabelling.

Get the scrape pool of this target.

Get the scrape URL of this target.

Get the global URL of this target.

Get the last error reported for this target.

Get the time when the last scrape occurred.

Get the duration that the last scrape ran for in seconds.

Get the health status of this target.

Get the scrape interval of this target.

Get the scrape timeout of this target.