pub struct AlertingRule { /* private fields */ }
An alerting rule.

Implementations

Get a list of active alerts fired due to this alerting rule.

Get a set of annotations set for this rule.

Get the duration that Prometheus waits for before firing for this rule.

Get the health state of this rule.

Get a set of labels defined for this rule.

Get the name of this rule.

Get the PromQL expression that is evaluated as part of this rule.