Struct prometheus_http_query::response::BuildInformation
source · pub struct BuildInformation { /* private fields */ }Expand description
An object containing Prometheus server build information.
Implementations
sourceimpl BuildInformation
impl BuildInformation
sourcepub fn build_user(&self) -> &str
pub fn build_user(&self) -> &str
Get the user who built the server.
sourcepub fn build_date(&self) -> &PrimitiveDateTime
pub fn build_date(&self) -> &PrimitiveDateTime
Get the date at which the server was built.
sourcepub fn go_version(&self) -> &str
pub fn go_version(&self) -> &str
Get the Go version that was used to build the server.