Struct prometheus_http_query::response::TsdbStatistics
source · pub struct TsdbStatistics { /* private fields */ }Expand description
Prometheus TSDB statistics.
Implementations
sourceimpl TsdbStatistics
impl TsdbStatistics
sourcepub fn head_stats(&self) -> HeadStatistics
pub fn head_stats(&self) -> HeadStatistics
Get the head block data.
sourcepub fn series_count_by_metric_name(&self) -> &[TsdbItemCount]
pub fn series_count_by_metric_name(&self) -> &[TsdbItemCount]
Get a list of metric names and their series count.
sourcepub fn label_value_count_by_label_name(&self) -> &[TsdbItemCount]
pub fn label_value_count_by_label_name(&self) -> &[TsdbItemCount]
Get a list of label names and their value count.
sourcepub fn memory_in_bytes_by_label_name(&self) -> &[TsdbItemCount]
pub fn memory_in_bytes_by_label_name(&self) -> &[TsdbItemCount]
Get a list of label names and memory used in bytes.
sourcepub fn series_count_by_label_value_pair(&self) -> &[TsdbItemCount]
pub fn series_count_by_label_value_pair(&self) -> &[TsdbItemCount]
Get a list of label name/value pairs and their series count.