pub struct InstantQueryBuilder { /* private fields */ }
A builder object used to set some query parameters in the context of an instant query before sending the query on its way.

Implementations

Set the evaluation timestamp (Unix timestamp in seconds, e.g. 1659182624). If this is not set the evaluation timestamp will default to the current Prometheus server time. See also: Prometheus API documentation

Set the evaluation timeout (milliseconds, e.g. 1000). If this is not set the timeout will default to the value of the “-query.timeout” flag of the Prometheus server. See also: Prometheus API documentation

Instruct Prometheus to compile query statistics as part of the API response.

Execute the instant query (using HTTP GET) and return the parsed API response.

Execute the instant query (using HTTP POST) and return the parsed API response. Using a POST request is useful in the context of larger PromQL queries when the size of the final URL may break Prometheus’ or an intermediate proxies’ URL character limits.