Struct prometheus_http_query::RangeVector
source · [−]pub struct RangeVector(pub String);Expand description
An range vector expression that can be further operated on with functions/aggregations
or passed to a Client in order to evaluate.
Tuple Fields
0: StringTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Convert a Selector to a RangeVector.
use prometheus_http_query::{Selector, RangeVector, Error};
use std::convert::TryInto;
fn main() -> Result<(), Error> {
let v: Result<RangeVector, Error> = Selector::new()
.metric("some_metric")?
.range("1m30s")?
.try_into();
assert!(v.is_ok());
Ok(())
}Auto Trait Implementations
impl RefUnwindSafe for RangeVector
impl Send for RangeVector
impl Sync for RangeVector
impl Unpin for RangeVector
impl UnwindSafe for RangeVector