pub struct Selector<'a> { /* private fields */ }
A time series selector that is gradually built from a metric name and/or a set of label matchers.

Implementations

Create a new instance of Selector.

Select a metric name for this Selector.

use prometheus_http_query::Selector;

let select = Selector::new().metric("http_requests_total");

// This is equal to:
let other_select = Selector::new().eq("__name__", "http_requests_total");

assert_eq!(select, other_select);

Append a label matcher to the set of matchers of Selector that selects labels that match the provided string.
PromQL equivalent: http_requests_total{job="apiserver"}

use prometheus_http_query::Selector;

let select = Selector::new()
    .metric("http_requests_total")
    .eq("job", "apiserver")
    .to_string();

let expected = r#"{__name__="http_requests_total",job="apiserver"}"#.to_string();

assert_eq!(select, expected);

Append a label matcher to the set of matchers of Selector that selects labels that do not match the provided string.
PromQL equivalent: http_requests_total{job!="apiserver"}

use prometheus_http_query::Selector;

let select = Selector::new()
    .metric("http_requests_total")
    .ne("job", "apiserver")
    .to_string();

let expected = r#"{__name__="http_requests_total",job!="apiserver"}"#.to_string();

assert_eq!(select, expected);

Append a label matcher to the set of matchers of Selector that selects labels that regex-match the provided string. PromQL equivalent: http_requests_total{job=~"apiserver"}

use prometheus_http_query::Selector;

let select = Selector::new()
    .metric("http_requests_total")
    .regex_eq("job", "apiserver")
    .to_string();

let expected = r#"{__name__="http_requests_total",job=~"apiserver"}"#.to_string();

assert_eq!(select, expected);

Append a label matcher to the set of matchers of Selector that selects labels that do not regex-match the provided string.
PromQL equivalent: http_requests_total{job!~"apiserver"}

use prometheus_http_query::Selector;

let select = Selector::new()
    .metric("http_requests_total")
    .regex_ne("job", "apiserver")
    .to_string();

let expected = r#"{__name__="http_requests_total",job!~"apiserver"}"#.to_string();

assert_eq!(select, expected);