Struct prometheus_http_query::response::ActiveTarget
source · pub struct ActiveTarget { /* private fields */ }Expand description
A single active target.
Implementations
sourceimpl ActiveTarget
impl ActiveTarget
sourcepub fn discovered_labels(&self) -> &HashMap<String, String>
pub fn discovered_labels(&self) -> &HashMap<String, String>
Get a set of unmodified labels as before relabelling occurred.
sourcepub fn scrape_pool(&self) -> &str
pub fn scrape_pool(&self) -> &str
Get the scrape pool of this target.
sourcepub fn scrape_url(&self) -> &Url
pub fn scrape_url(&self) -> &Url
Get the scrape URL of this target.
sourcepub fn global_url(&self) -> &Url
pub fn global_url(&self) -> &Url
Get the global URL of this target.
sourcepub fn last_error(&self) -> &str
pub fn last_error(&self) -> &str
Get the last error reported for this target.
sourcepub fn last_scrape(&self) -> &OffsetDateTime
pub fn last_scrape(&self) -> &OffsetDateTime
Get the time when the last scrape occurred.
sourcepub fn last_scrape_duration(&self) -> f64
pub fn last_scrape_duration(&self) -> f64
Get the duration that the last scrape ran for in seconds.
sourcepub fn scrape_interval(&self) -> &Duration
pub fn scrape_interval(&self) -> &Duration
Get the scrape interval of this target.
sourcepub fn scrape_timeout(&self) -> &Duration
pub fn scrape_timeout(&self) -> &Duration
Get the scrape timeout of this target.