Struct prometheus_http_query::response::AlertingRule
source · [−]pub struct AlertingRule { /* private fields */ }Expand description
An alerting rule.
Implementations
Get a set of annotations set for this rule.
Get the duration that Prometheus waits for before firing for this rule.